@@ -1,7 +1,7 @@
 // qmidinetUdpDevice.h
 //
 /****************************************************************************
-   Copyright (C) 2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -54,7 +54,8 @@ public:
 	static qmidinetUdpDevice *getInstance();
 
 	// Device initialization method.
-	bool open(const QString& sInterface, int iUdpPort = 21928, int iNumPorts = 1);
+	bool open(const QString& sInterface,
+		const QString& sUdpAddr, int iUdpPort, int iNumPorts = 1);
 
 	// Device termination method.
 	void close();
